@@ -3,14 +3,14 @@ package XML::Grammar::FictionBase::Event;
 
 use MooX 'late';
 
-use XML::Grammar::Fiction::FromProto::Nodes;
+use XML::Grammar::Fiction::FromProto::Node;
 
 has 'type' => (isa => "Str", is => "ro");
 has 'tag' => (isa => "Maybe[Str]", is => "ro", predicate => '_has_tag',);
 has 'elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 has 'tag_elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 
-our $VERSION = '0.14.0';
+our $VERSION = '0.14.1';
 
 sub is_tag_of_name
 {
@@ -49,7 +49,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.14.0
+version 0.14.1
 
 =head1 VERSION
 
