@@ -11,6 +11,16 @@ use XML::Grammar::Fiction::Err;
 use XML::Grammar::Fiction::Struct::Tag;
 use XML::Grammar::FictionBase::Event;
 
+use XML::Grammar::Fiction::FromProto::Node::WithContent;
+use XML::Grammar::Fiction::FromProto::Node::Element;
+use XML::Grammar::Fiction::FromProto::Node::List;
+use XML::Grammar::Fiction::FromProto::Node::Text;
+use XML::Grammar::Fiction::FromProto::Node::Saying;
+use XML::Grammar::Fiction::FromProto::Node::Description;
+use XML::Grammar::Fiction::FromProto::Node::Paragraph;
+use XML::Grammar::Fiction::FromProto::Node::InnerDesc;
+use XML::Grammar::Fiction::FromProto::Node::Comment;
+
 extends("XML::Grammar::FictionBase::FromProto::Parser::LineIterator");
 
 has "_tags_stack" =>
@@ -897,7 +907,7 @@ sub _main_loop_iter_body
 }
 
 
-our $VERSION = '0.14.0';
+our $VERSION = '0.14.1';
 
 
 sub process_text
@@ -927,7 +937,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.14.0
+version 0.14.1
 
 =head1 SYNOPSIS
 
@@ -969,7 +979,7 @@ XML-like grammars.
 
 =head1 VERSION
 
-Version 0.14.0
+Version 0.14.1
 
 =head1 METHODS
 
